@@ -5,27 +5,13 @@ from typing import Union
 import numpy as np
 import xarray as xr
 
-# DEFAULT PATHS
-
-# TODO: Issue #386. Remove this?
-BUCKET = Path("solar-pv-nowcasting-data")
-
 # Satellite data
-# TODO: Issue #386. Remove this?
+# TODO: remove this?
 SAT_FILENAME = "gs://" + str(
-    BUCKET / "satellite/EUMETSAT/SEVIRI_RSS/OSGB36/all_zarr_int16_single_timestep.zarr"
+    Path("solar-pv-nowcasting-data")
+    / "satellite/EUMETSAT/SEVIRI_RSS/OSGB36/all_zarr_int16_single_timestep.zarr"
 )
 
-# Solar PV data
-# TODO: Issue #386. Remove these?
-PV_PATH = BUCKET / "PV/PVOutput.org"
-PV_FILENAME = PV_PATH / "UK_PV_timeseries_batch.nc"
-PV_METADATA_FILENAME = PV_PATH / "UK_PV_metadata.csv"
-
-# Numerical weather predictions.
-# TODO: Issue #386. Remove this?
-NWP_FILENAME = "gs://" + str(BUCKET / "NWP/UK_Met_Office/UKV_zarr")
-
 # Typing
 Array = Union[xr.DataArray, np.ndarray]
 PV_SYSTEM_ID: str = "pv_system_id"
@@ -129,3 +115,5 @@ SPATIAL_AND_TEMPORAL_LOCATIONS_OF_EACH_EXAMPLE_FILENAME = (
     "spatial_and_temporal_locations_of_each_example.csv"
 )
 SPATIAL_AND_TEMPORAL_LOCATIONS_COLUMN_NAMES = ("t0_datetime_UTC", "x_center_OSGB", "y_center_OSGB")
+
+LOG_LEVELS = ("DEBUG", "INFO", "WARNING", "ERROR")
